@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 
-import six
 import os
 import sys
 import unittest
@@ -168,7 +167,7 @@ class NotificationTestCaseGeneric(NotificationTestBase):
     def test_if_is_notifying_pipe(self):
         in_, out = os.pipe()
         self.sock_queue.register(in_)
-        os.write(out, six.b("\x00"))
+        os.write(out, b"\x00")
         data = self.sock_queue.poll(1)
         self.assertEqual((in_, 1), data[0])
 
@@ -181,7 +180,7 @@ class NotificationTestCaseGeneric(NotificationTestBase):
 
     def test_if_socket_is_notifying_udp(self):
         self.sock_queue.register(self.socket_server_udp)
-        self.socket_udp.sendto(six.b("test"), self.addr_udp)
+        self.socket_udp.sendto(b"test", self.addr_udp)
         data = self.sock_queue.poll(1)
         self.assertEqual((self.socket_server_udp, 1), data[0])
 
@@ -191,7 +190,7 @@ class NotificationTestCaseGeneric(NotificationTestBase):
         s, a = self.socket_server.accept()
 
         self.sock_queue.register(s)
-        self.socket.send(six.b("data"))
+        self.socket.send(b"data")
         data = self.sock_queue.poll(1)
         self.assertEqual((s, 1), data[0])
         self.socket.shutdown(socket.SHUT_RDWR)
